SWxSchema Documentation
-------------------------

This is the documentation for the `swxschema`` Python Package.

.. toctree::
   :maxdepth: 2

   whatsnew/index
   user-guide/index
   dev-guide/index
   api
